pynrc.nrc\_utils.gen\_unconvolved\_point\_source\_image
=======================================================

.. currentmodule:: pynrc.nrc_utils

.. autofunction:: gen_unconvolved_point_source_image